package com.prolog.rdc.tms.service.basicConfigure;

import java.util.List;

import com.prolog.framework.core.pojo.Page;
import com.prolog.rdc.tms.model.dto.basicConfigure.SysAlertConfigurationQueryDTO;
import com.prolog.rdc.tms.model.dto.basicConfigure.SysAlertUsersQueryDTO;
import com.prolog.rdc.tms.model.vo.basicConfigure.*;

/**
 * 
 *
 * 基础配置-预警配置服务层
 *
 * @className :SysAlertConfigurationService
 * @author :fanzw
 * @creationTime :2022/01/18
 * @description :
 *
 * @modifier :fanzw
 * @modifyTime :2022/01/18
 * @reviseRemarks:
 *
 * @version :1.0.0
 *
 */
public interface SysAlertConfigurationService {

	/**
	 * 预警配置查询
	 * 
	 * @param sysAlertConfigurationQueryVO
	 * @return
	 */
	Page<SysAlertConfigurationQueryDTO> listAlertConfigurationData(SysAlertConfigurationQueryVO sysAlertConfigurationQueryVO);


	/**
	 * 预警配置查询
	 *
	 * @param sysAlertConfigurationQueryVO
	 * @return
	 */
	List<SysAlertConfigurationQueryDTO> alertConfigurationQuery(SysAlertConfigurationQueryVO sysAlertConfigurationQueryVO);


	/**
	 * 预警配置用户查询
	 * 
	 * @param sysAlertUsersQueryVO
	 * @return
	 */
	List<SysAlertUsersQueryDTO> listAlertUsersData(SysAlertUsersQueryVO sysAlertUsersQueryVO);

	/**
	 * 预警配置保存
	 * 
	 * @param sysAlertConfigurationSaveVO
	 */
	void saveAlertConfigurationData(SysAlertConfigurationSaveVO sysAlertConfigurationSaveVO);

	/**
	 * 预警配置修改
	 * 
	 * @param sysAlertConfigurationUpdateVO
	 */
	void updateAlertConfigurationData(SysAlertConfigurationUpdateVO sysAlertConfigurationUpdateVO);

	/**
	 * 预警配置删除
	 * 
	 * @param sysAlertConfigurationDeleteVOs
	 */
	void deleteAlertConfigurationData(List<SysAlertConfigurationDeleteVO> sysAlertConfigurationDeleteVOs);

	/**
	 * 预警配置用户删除
	 * 
	 * @param sysAlertUsersDeleteVOs
	 */
	void deleteAlertUsersData(List<SysAlertUsersDeleteVO> sysAlertUsersDeleteVOs);

}
